@@ -234,6 +234,7 @@ class ExecuteRemoteBatch():
       commentPattern  = re.compile('\s*#.*')
       inDistributorSection = False
 
+      configured = False
       configFilePath = os.path.join(self.configurationDirectory,self.distributorConfigurationFile)
       try:
          fpConfig = open(configFilePath,'r')
@@ -293,6 +294,7 @@ class ExecuteRemoteBatch():
                            self.logger.log(logging.WARNING,getLogMessage("Undefined key = value pair %s = %s" % (key,value)))
                else:
                   eof = True
+                  configured = True
          except (IOError,OSError):
             self.logger.log(logging.ERROR,getLogMessage("%s could not be read" % (configFilePath)))
          finally:
@@ -300,20 +302,20 @@ class ExecuteRemoteBatch():
       except (IOError,OSError):
          self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (configFilePath)))
 
-      configured = True
-      if os.path.isdir(self.configData['dataDirectory']):
-         self.dataDirectory = self.configData['dataDirectory']
-      else:
-         message = "Specified dataDirectory does not exist: %s" % (self.configData['dataDirectory'])
-         self.logger.log(logging.ERROR,getLogMessage(message))
-         configured = False
+      if configured:
+         if os.path.isdir(self.configData['dataDirectory']):
+            self.dataDirectory = self.configData['dataDirectory']
+         else:
+            message = "Specified dataDirectory does not exist: %s" % (self.configData['dataDirectory'])
+            self.logger.log(logging.ERROR,getLogMessage(message))
+            configured = False
 
-      if os.path.isdir(self.configData['binDirectory']):
-         self.binDirectory = self.configData['binDirectory']
-      else:
-         message = "Specified binDirectory does not exist: %s" % (self.configData['binDirectory'])
-         self.logger.log(logging.ERROR,getLogMessage(message))
-         configured = False
+         if os.path.isdir(self.configData['binDirectory']):
+            self.binDirectory = self.configData['binDirectory']
+         else:
+            message = "Specified binDirectory does not exist: %s" % (self.configData['binDirectory'])
+            self.logger.log(logging.ERROR,getLogMessage(message))
+            configured = False
 
       return(configured)
 
@@ -615,9 +617,9 @@ class ExecuteRemoteBatch():
       self.waitForJobsInfo[instance]['knownSite']             = self.clusterHost
       self.waitForJobsInfo[instance]['remoteJobId']           = self.remoteJobIdNumber
       self.waitForJobsInfo[instance]['recentJobStatus']       = '?'
-      completeRemoteJobIndexes = self.remoteJobMonitor.waitForBatchJobs(self.waitForJobsInfo,
-                                                                        self.progressReport,
-                                                                        self.abortGlobal)
+      completeRemoteJobIndexes = self.remoteJobMonitor.waitForRedundantJobs(self.waitForJobsInfo,
+                                                                            self.progressReport,
+                                                                            self.abortGlobal)
 
 
    def executeFetch(self):
