@@ -26,7 +26,7 @@
 #
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
-__version__ = '3.2.8'
+__version__ = '3.4.2'
 
 import sys
 import os
@@ -184,7 +184,9 @@ class JobStatus:
                self.__natsort(instanceIds)
                for instanceId in instanceIds:
                   runName,jobQueue,jobSite,jobStatus,jobStage = reportedJobs[localJobId][instanceId]
-                  if jobQueue != '?':
+                  if   '@' in jobSite:
+                     queueSite = jobSite
+                  elif jobQueue != '?':
                      queueSite = jobQueue + '@' + jobSite
                   else:
                      queueSite = jobSite
