@@ -879,6 +879,21 @@ class SitesInfo:
       return(sitesWithoutKeyValue)
 
 
+   def getSiteWithVenueAndPort(self,
+                               venue,
+                               venuePort):
+      siteWithVenueAndPort = ""
+
+      for siteName in self.sites:
+         venues = self.sites[siteName]['venues']
+         if venue in venues:
+            if venuePort == self.sites[siteName]['venuePort']:
+               siteWithVenueAndPort = siteName
+               break
+
+      return(siteWithVenueAndPort)
+
+
    def siteExists(self,
                   siteName):
       return(siteName in self.sites)
