@@ -42,9 +42,12 @@ from errno import EPIPE
 from hubzero.submit.LogMessage   import getLogIDMessage as getLogMessage
 from hubzero.submit.JobStatistic import JobStatistic
 
+HARVESTINFORMATION = ".__harvest_information"
+
 class VenueMechanismCore:
    def __init__(self,
                 timeHistoryLogs,
+                disableJobMonitoring,
                 siteInfo,
                 toolFilesInfo,
                 dockerImageInfo,
@@ -58,6 +61,7 @@ class VenueMechanismCore:
                 event):
       self.logger                = logging.getLogger(__name__)
       self.timeHistoryLogs       = copy.copy(timeHistoryLogs)
+      self.disableJobMonitoring  = disableJobMonitoring
       self.siteInfo              = copy.copy(siteInfo)
       self.toolFilesInfo         = copy.copy(toolFilesInfo)
       self.dockerImageInfo       = copy.copy(dockerImageInfo)
@@ -77,6 +81,8 @@ class VenueMechanismCore:
       self.venueMechanism    = ''
       self.remoteBatchSystem = ''
       self.enteredCommand    = ""
+      self.destination       = ""
+      self.venue             = ""
 
       self.isMultiCoreRequest = isMultiCoreRequest
       self.nCpus              = nCpus
@@ -104,6 +110,16 @@ class VenueMechanismCore:
       self.instanceDirectory = ""
       self.stageInTarFile    = ""
 
+      self.batchLogPath               = ""
+      self.appScriptPath              = ""
+      self.batchScriptPath            = ""
+      self.nodeFilePath               = ""
+      self.toolInputTemplateFilePath  = ""
+      self.toolOutputTemplateFilePath = ""
+      self.remoteJobIdNumber          = ""
+
+      self.instancesInitialJobStatus = []
+
 
    def _writeToStdout(self,
                       message):
@@ -352,7 +368,10 @@ class VenueMechanismCore:
          matchingFiles = filter(reFiles.search,dirFiles)
          if len(matchingFiles) > 0:
             for matchingFile in matchingFiles:
-               os.remove(os.path.join(self.instanceDirectory,matchingFile))
+               try:
+                  os.remove(os.path.join(self.instanceDirectory,matchingFile))
+               except:
+                  pass
 
 
    def stageFilesToInstanceDirectory(self):
@@ -365,10 +384,13 @@ class VenueMechanismCore:
             if self.instanceDirectory != currentWorkingDirectory:
                if os.path.isdir(self.instanceDirectory):
                   if self.stageInTarFile != "":
-                     srcPath = os.path.join(currentWorkingDirectory,self.stageInTarFile)
+                     stageInTarFile = self.stageInTarFile
+                     srcPath = os.path.join(currentWorkingDirectory,stageInTarFile)
                      if os.path.exists(srcPath):
-                        dstPath = os.path.join(self.instanceDirectory,self.stageInTarFile)
+                        dstPath = os.path.join(self.instanceDirectory,stageInTarFile)
                         os.rename(srcPath,dstPath)
+                     else:
+                        self.logger.log(logging.DEBUG,getLogMessage("stageFilesToInstanceDirectory: missing stageInTarFile"))
 
 
    def registerJob(self):
@@ -501,3 +523,131 @@ class VenueMechanismCore:
                         self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (fileToAppend)))
 
 
+   def cleanupPegasusFiles(self):
+      for ftype in '.dax','_sites.xml','.pegasusrc','_tc.txt':
+         pegasusFile = os.path.join(self.instanceDirectory,"%s_%s%s" % (self.localJobId,self.instanceId,ftype))
+         if os.path.isfile(pegasusFile):
+            try:
+               os.remove(pegasusFile)
+            except:
+               pass
+         else:
+            pegasusFile = os.path.join(self.instanceDirectory,"%s%s" % (self.localJobId,ftype))
+            if os.path.isfile(pegasusFile):
+               try:
+                  os.remove(pegasusFile)
+               except:
+                  pass
+
+      pegasusFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.localJobId,self.instanceId))
+      if os.path.exists(pegasusFile):
+         if(os.path.getsize(pegasusFile) == 0):
+            try:
+               os.remove(pegasusFile)
+            except:
+               pass
+
+
+   def cleanupScriptTemplateLogFiles(self):
+      for scriptTemplateLogFile in [self.batchScriptPath,self.appScriptPath,self.nodeFilePath,
+                                    self.toolInputTemplateFilePath,self.toolOutputTemplateFilePath,
+                                    self.batchLogPath]:
+         if os.path.isfile(scriptTemplateLogFile):
+            os.remove(scriptTemplateLogFile)
+
+
+   def cleanupStageInTarFile(self):
+      stageInTarFile = os.path.join(self.instanceDirectory,self.stageInTarFile)
+      if os.path.isfile(stageInTarFile):
+         try:
+            os.remove(stageInTarFile)
+         except:
+            pass
+
+      stageInTarFile += '.gz'
+      if os.path.isfile(stageInTarFile):
+         try:
+            os.remove(stageInTarFile)
+         except:
+            pass
+
+
+   def cleanupStageOutTarFile(self):
+      stageOutTarFile = "%s_%s_output.tar" % (self.localJobId,self.instanceId)
+      if os.path.isfile(stageOutTarFile):
+         try:
+            os.remove(stageOutTarFile)
+         except:
+            pass
+
+      stageOutTarFile += '.gz'
+      if os.path.isfile(stageOutTarFile):
+         try:
+            os.remove(stageOutTarFile)
+         except:
+            pass
+
+
+   def setInstancesInitialJobStatus(self,
+                                    instancesInitialJobStatus):
+      self.instancesInitialJobStatus = instancesInitialJobStatus
+
+
+   def writeHarvestInformationFile(self,
+                                   runType=None,
+                                   filesToRemove=None,
+                                   emptyFilesToRemove=None):
+      harvestInformationFile = "%s.%s_%s" % (HARVESTINFORMATION,self.localJobId,self.instanceId)
+      harvestInformationPath = os.path.join(self.instanceDirectory,harvestInformationFile)
+      try:
+         fpHarvestInformationFile = open(harvestInformationPath,'w')
+         try:
+            if runType:
+               fpHarvestInformationFile.write("runType = %s\n" % (runType))
+            fpHarvestInformationFile.write("venueMechanism = %s\n" % (self.venueMechanism))
+            fpHarvestInformationFile.write("localJobId = %s\n" % (self.localJobId))
+            fpHarvestInformationFile.write("instanceId = %s\n" % (self.instanceId))
+            fpHarvestInformationFile.write("nInstances = %d\n" % (self.nInstances))
+            fpHarvestInformationFile.write("runName = %s\n" % (self.runName))
+            fpHarvestInformationFile.write("isParametric = %s\n" % (self.isParametric))
+            fpHarvestInformationFile.write("isMultiCoreRequest = %s\n" % (self.isMultiCoreRequest))
+            fpHarvestInformationFile.write("nCpus = %d\n" % (self.nCpus))
+
+            if self.jobStatistics[self.jobIndex]['event']:
+               fpHarvestInformationFile.write("event = %s\n" % (self.jobStatistics[self.jobIndex]['event']))
+            if self.destination:
+               fpHarvestInformationFile.write("destination = %s\n" % (self.destination))
+            if self.jobStatistics[self.jobIndex]['venue']:
+               fpHarvestInformationFile.write("venue = %s\n" % (self.jobStatistics[self.jobIndex]['venue']))
+            if self.jobStatistics[self.jobIndex]['remoteJobIdNumber']:
+               fpHarvestInformationFile.write("remoteJobIdNumber = %s\n" % (self.jobStatistics[self.jobIndex]['remoteJobIdNumber']))
+            if self.stageInTarFile:
+               fpHarvestInformationFile.write("stageInTarFile = %s\n" % (self.stageInTarFile))
+            if self.batchLogPath:
+               fpHarvestInformationFile.write("batchLogPath = %s\n" % (self.batchLogPath))
+            if self.appScriptPath:
+               fpHarvestInformationFile.write("appScriptPath = %s\n" % (self.appScriptPath))
+            if self.batchScriptPath:
+               fpHarvestInformationFile.write("batchScriptPath = %s\n" % (self.batchScriptPath))
+            if self.nodeFilePath:
+               fpHarvestInformationFile.write("nodeFilePath = %s\n" % (self.nodeFilePath))
+            if self.toolInputTemplateFilePath:
+               fpHarvestInformationFile.write("toolInputTemplateFilePath = %s\n" % (self.toolInputTemplateFilePath))
+            if self.toolOutputTemplateFilePath:
+               fpHarvestInformationFile.write("toolOutputTemplateFilePath = %s\n" % (self.toolOutputTemplateFilePath))
+            if filesToRemove:
+               fpHarvestInformationFile.write("filesToRemove = %s\n" % (','.join(filesToRemove)))
+            if emptyFilesToRemove:
+               fpHarvestInformationFile.write("emptyFilesToRemove = %s\n" % (','.join(emptyFilesToRemove)))
+            if self.x509SubmitProxy:
+               fpHarvestInformationFile.write("x509SubmitProxy = %s\n" % (self.x509SubmitProxy))
+         except (IOError,OSError):
+            self.logger.log(logging.ERROR,getLogMessage("%s could not be written" % (harvestInformationFile)))
+            self._writeToStderr("%s could not be written\n" % (harvestInformationFile))
+         finally:
+            fpHarvestInformationFile.close()
+      except (IOError,OSError):
+         self.logger.log(logging.ERROR,getLogMessage("%s could not be opened" % (harvestInformationFile)))
+         self._writeToStderr("%s could not be opened\n" % (harvestInformationFile))
+
+
