@@ -83,6 +83,7 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
                 useEnvironment,
                 environment,
                 isMultiCoreRequest,
+                disableJobMonitoring,
                 siteInfo,
                 toolFilesInfo,
                 dockerImageInfo,
@@ -99,7 +100,8 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
                 useSetup,
                 pegasusVersion,
                 pegasusHome):
-      VenueMechanismCore.__init__(self,timeHistoryLogs,siteInfo,toolFilesInfo,dockerImageInfo,submissionScriptsInfo,managerInfo,
+      VenueMechanismCore.__init__(self,timeHistoryLogs,disableJobMonitoring,
+                                       siteInfo,toolFilesInfo,dockerImageInfo,submissionScriptsInfo,managerInfo,
                                        remoteMonitors,isMultiCoreRequest,nCpus,nNodes,ppn,event)
 
       self.logger                           = logging.getLogger(__name__)
@@ -1095,7 +1097,10 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
                self.logger.log(logging.INFO,getLogMessage("command = " + command))
                exitStatus,stdOutput,stdError = self.executeCommand(command)
                if exitStatus == 0:
-                  os.remove(stageOutTarFile)
+                  try:
+                     os.remove(stageOutTarFile)
+                  except:
+                     pass
                else:
                   self.jobStatistics[self.jobIndex]['exitCode'] = 12
                   if stdOutput != "":
@@ -1170,21 +1175,7 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
             if os.path.isdir(inProcessDirectoryName):
                shutil.rmtree(inProcessDirectoryName,True)
 
-            for ftype in '.dax','_sites.xml','.pegasusrc','_tc.txt':
-               pegasusFile = os.path.join(self.instanceDirectory,"%s_%s%s" % (self.localJobId,self.instanceId,ftype))
-               if os.path.isfile(pegasusFile):
-                  os.remove(pegasusFile)
-               else:
-                  pegasusFile = os.path.join(self.instanceDirectory,"%s%s" % (self.localJobId,ftype))
-                  if os.path.isfile(pegasusFile):
-                     os.remove(pegasusFile)
-            pegasusFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.localJobId,self.instanceId))
-            if os.path.exists(pegasusFile):
-               if(os.path.getsize(pegasusFile) == 0):
-                  os.remove(pegasusFile)
-            stageInTarFile = os.path.join(self.instanceDirectory,self.stageInTarFile)
-            if os.path.isfile(stageInTarFile):
-               os.remove(stageInTarFile)
+            self.cleanupPegasusFiles()
          else:
             if   not self.sharedUserSpace and self.stageFiles:
                remoteWorkingDirectory = self.workingDirectory.replace('$','\$')
@@ -1198,32 +1189,10 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
                   os.environ['X509_USER_PROXY'] = self.x509SubmitProxy
                   self.logger.log(logging.INFO,getLogMessage(self.executeSSHCommand(command,self.tunnelDesignator)[1]))
             elif self.sharedUserSpace and self.stageFiles:
-               stageOutTarFile = "%s_%s_output.tar.gz" % (self.localJobId,self.instanceId)
-               if os.path.isfile(stageOutTarFile):
-                  os.remove(stageOutTarFile)
-               else:
-                  stageOutTarFile = "%s_%s_output.tar" % (self.localJobId,self.instanceId)
-                  if os.path.isfile(stageOutTarFile):
-                     os.remove(stageOutTarFile)
+               self.cleanupStageOutTarFile()
 
-         if self.batchScriptPath:
-            if os.path.isfile(self.batchScriptPath):
-               os.remove(self.batchScriptPath)
-         if self.appScriptPath:
-            if os.path.isfile(self.appScriptPath):
-               os.remove(self.appScriptPath)
-         if self.nodeFilePath:
-            if os.path.isfile(self.nodeFilePath):
-               os.remove(self.nodeFilePath)
-         if self.toolInputTemplateFilePath:
-            if os.path.isfile(self.toolInputTemplateFilePath):
-               os.remove(self.toolInputTemplateFilePath)
-         if self.toolOutputTemplateFilePath:
-            if os.path.isfile(self.toolOutputTemplateFilePath):
-               os.remove(self.toolOutputTemplateFilePath)
-         if self.batchLogPath:
-            if os.path.isfile(self.batchLogPath):
-               os.remove(self.batchLogPath)
+         self.cleanupStageInTarFile()
+         self.cleanupScriptTemplateLogFiles()
 
          self.filesCleanedup = True
 
