@@ -79,6 +79,7 @@ class VenueMechanismLocal(VenueMechanismCore):
                 useEnvironment,
                 environment,
                 isMultiCoreRequest,
+                disableJobMonitoring,
                 siteInfo,
                 toolFilesInfo,
                 dockerImageInfo,
@@ -95,7 +96,8 @@ class VenueMechanismLocal(VenueMechanismCore):
                 useSetup,
                 pegasusVersion,
                 pegasusHome):
-      VenueMechanismCore.__init__(self,timeHistoryLogs,siteInfo,toolFilesInfo,dockerImageInfo,submissionScriptsInfo,managerInfo,
+      VenueMechanismCore.__init__(self,timeHistoryLogs,disableJobMonitoring,
+                                       siteInfo,toolFilesInfo,dockerImageInfo,submissionScriptsInfo,managerInfo,
                                        remoteMonitors,isMultiCoreRequest,nCpus,nNodes,ppn,event)
 
       self.logger                           = logging.getLogger(__name__)
@@ -678,6 +680,8 @@ class VenueMechanismLocal(VenueMechanismCore):
          commandArgs.append(self.instanceDirectory)
          commandArgs.append(remoteScratchDirectory)
          commandArgs.append(os.path.join('.',os.path.basename(self.batchScriptPath)))
+         if self.disableJobMonitoring:
+            commandArgs.append('1')
          if self.logUserRemotely:
             hubUserHash = self.remoteIdentityManager.queryUserHash(self.siteInfo['identityManagers'],
                                                                    self.hubUserName,
@@ -715,7 +719,8 @@ class VenueMechanismLocal(VenueMechanismCore):
                                                                     self.siteMonitorDesignator,
                                                                     self.remoteJobIdNumber,str(self.hubUserId),
                                                                     self.enteredCommand,
-                                                                    self.localJobId,self.nInstances,self.destination,
+                                                                    self.localJobId,self.nInstances,
+                                                                    self.instancesInitialJobStatus,self.destination,
                                                                     self.runName,self.nCpus,self.distributorPid)
                else:
                   self.remoteJobMonitor.postJobSubmission(self.siteInfo['siteName'],
@@ -870,7 +875,10 @@ class VenueMechanismLocal(VenueMechanismCore):
                self.logger.log(logging.INFO,getLogMessage("command = " + command))
                exitStatus,stdOutput,stdError = self.executeCommand(command)
                if exitStatus == 0:
-                  os.remove(stageOutTarFile)
+                  try:
+                     os.remove(stageOutTarFile)
+                  except:
+                     pass
                else:
                   self.jobStatistics[self.jobIndex]['exitCode'] = 12
                   if stdOutput != "":
@@ -937,21 +945,8 @@ class VenueMechanismLocal(VenueMechanismCore):
             inProcessDirectoryName = os.path.join(self.instanceDirectory,'InProcessResults')
             if os.path.isdir(inProcessDirectoryName):
                shutil.rmtree(inProcessDirectoryName,True)
-            for ftype in '.dax','_sites.xml','.pegasusrc','_tc.txt':
-               pegasusFile = os.path.join(self.instanceDirectory,"%s_%s%s" % (self.localJobId,self.instanceId,ftype))
-               if os.path.isfile(pegasusFile):
-                  os.remove(pegasusFile)
-               else:
-                  pegasusFile = os.path.join(self.instanceDirectory,"%s%s" % (self.localJobId,ftype))
-                  if os.path.isfile(pegasusFile):
-                     os.remove(pegasusFile)
-            pegasusFile = os.path.join(self.instanceDirectory,"%s_%s.stderr" % (self.localJobId,self.instanceId))
-            if os.path.exists(pegasusFile):
-               if(os.path.getsize(pegasusFile) == 0):
-                  os.remove(pegasusFile)
-            stageInTarFile = os.path.join(self.instanceDirectory,self.stageInTarFile)
-            if os.path.isfile(stageInTarFile):
-               os.remove(stageInTarFile)
+
+            self.cleanupPegasusFiles()
          elif self.remoteBatchSystem == 'BOINC':
             if self.jobSubmitted:
                if self.instanceId != "0":
@@ -970,33 +965,16 @@ class VenueMechanismLocal(VenueMechanismCore):
 
          if self.removeIdentity:
             if os.path.isfile(self.sshIdentityPath):
-               os.remove(self.sshIdentityPath)
-         if self.batchScriptPath:
-            if os.path.isfile(self.batchScriptPath):
-               os.remove(self.batchScriptPath)
-         if self.appScriptPath:
-            if os.path.isfile(self.appScriptPath):
-               os.remove(self.appScriptPath)
-         if self.nodeFilePath:
-            if os.path.isfile(self.nodeFilePath):
-               os.remove(self.nodeFilePath)
-         if self.toolInputTemplateFilePath:
-            if os.path.isfile(self.toolInputTemplateFilePath):
-               os.remove(self.toolInputTemplateFilePath)
-         if self.toolOutputTemplateFilePath:
-            if os.path.isfile(self.toolOutputTemplateFilePath):
-               os.remove(self.toolOutputTemplateFilePath)
-         if self.batchLogPath:
-            if os.path.isfile(self.batchLogPath):
-               os.remove(self.batchLogPath)
+               try:
+                  os.remove(self.sshIdentityPath)
+               except:
+                  pass
+
+         self.cleanupStageInTarFile()
+         self.cleanupScriptTemplateLogFiles()
+
          if self.sharedUserSpace and self.stageFiles:
-            stageOutTarFile = "%s_%s_output.tar.gz" % (self.localJobId,self.instanceId)
-            if os.path.isfile(stageOutTarFile):
-               os.remove(stageOutTarFile)
-            else:
-               stageOutTarFile = "%s_%s_output.tar" % (self.localJobId,self.instanceId)
-               if os.path.isfile(stageOutTarFile):
-                  os.remove(stageOutTarFile)
+            self.cleanupStageOutTarFile()
 
          self.filesCleanedup = True
 
